#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.dnb_robot_interfaces.generic_obj_frame_profile import GenericObjFrameProfile
from pycatia.dnb_robot_interfaces.generic_tool_profile import GenericToolProfile
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.dnb_robot_interfaces.generic_accuracy_profile import GenericAccuracyProfile
    from pycatia.dnb_robot_interfaces.generic_motion_profile import GenericMotionProfile


class RobGenericController(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RobGenericController
                | 
                | INTERFACE : DNBIARobGenericController
                | DESCRIPTION This allows add/remove and get/set of controller
                | profiles
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rob_generic_controller = com_object

    def add_accuracy_profile(self, profile: 'GenericAccuracyProfile') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddAccuracyProfile(GenericAccuracyProfile profile)
                | 
                |     Add a new Accuracy Profile into controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             interface pointer to Accuracy profile 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericAccuracyProfile profile:
        :rtype: None
        """

        return self.rob_generic_controller.AddAccuracyProfile(profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_accuracy_profile'
        # # vba_code = """
        # # Public Function add_accuracy_profile(rob_generic_controller)
        # #     Dim profile (2)
        # #     rob_generic_controller.AddAccuracyProfile profile
        # #     add_accuracy_profile = profile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_motion_profile(self, profile: 'GenericMotionProfile') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddMotionProfile(GenericMotionProfile profile)
                | 
                |     Add a new Motion Profile into controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             interface pointer to Motion profile 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericMotionProfile profile:
        :rtype: None
        """
        return self.rob_generic_controller.AddMotionProfile(profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_motion_profile'
        # # vba_code = """
        # # Public Function add_motion_profile(rob_generic_controller)
        # #     Dim profile (2)
        # #     rob_generic_controller.AddMotionProfile profile
        # #     add_motion_profile = profile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_obj_frame_profile(self, profile: GenericObjFrameProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddObjFrameProfile(GenericObjFrameProfile profile)
                | 
                |     Add a new ObjFrame Profile into controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             interface pointer to ObjFrame profile 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericObjFrameProfile profile:
        :rtype: None
        """
        return self.rob_generic_controller.AddObjFrameProfile(profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_obj_frame_profile'
        # # vba_code = """
        # # Public Function add_obj_frame_profile(rob_generic_controller)
        # #     Dim profile (2)
        # #     rob_generic_controller.AddObjFrameProfile profile
        # #     add_obj_frame_profile = profile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_tool_profile(self, i_profile: GenericToolProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddToolProfile(GenericToolProfile iProfile)
                | 
                |     Add a new Tool Profile into controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             interface pointer to tool profile 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericToolProfile i_profile:
        :rtype: None
        """
        return self.rob_generic_controller.AddToolProfile(i_profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_tool_profile'
        # # vba_code = """
        # # Public Function add_tool_profile(rob_generic_controller)
        # #     Dim iProfile (2)
        # #     rob_generic_controller.AddToolProfile iProfile
        # #     add_tool_profile = iProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_accuracy_profile(self, name: str, profile: 'GenericAccuracyProfile') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccuracyProfile(CATBSTR name,
                | GenericAccuracyProfile profile)
                | 
                |     Get Accuracy profile given name.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the Accuracy profile.
                |             
                |         profile
                |             This outer parameter contains interface pointer to Accuracy
                |             profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param GenericAccuracyProfile profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetAccuracyProfile(name, profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_accuracy_profile'
        # # vba_code = """
        # # Public Function get_accuracy_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.GetAccuracyProfile name
        # #     get_accuracy_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_accuracy_profile_count(self, count: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccuracyProfileCount(long count)
                | 
                |     Get number of Accuracy profiles in controller.
                | 
                |     Parameters:
                | 
                |         count
                |             This outer parameter contains number of Accuracy profiles.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int count:
        :rtype: None
        """
        return self.rob_generic_controller.GetAccuracyProfileCount(count)

    def get_accuracy_profiles(self, profiles: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAccuracyProfiles(CATSafeArrayVariant profiles)
                | 
                |     Get Accuracy profiles list in controller.
                | 
                |     Parameters:
                | 
                |         profiles
                |             This outer parameter contains Accuracy profile list.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param tuple profiles:
        :rtype: None
        """
        return self.rob_generic_controller.GetAccuracyProfiles(profiles)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_accuracy_profiles'
        # # vba_code = """
        # # Public Function get_accuracy_profiles(rob_generic_controller)
        # #     Dim profiles (2)
        # #     rob_generic_controller.GetAccuracyProfiles profiles
        # #     get_accuracy_profiles = profiles
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_current_accuracy_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCurrentAccuracyProfile(CATBSTR profile)
                | 
                |     Get current Accuracy profile name used in controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This outer parameter contains Accuracy profile name.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetCurrentAccuracyProfile(profile)

    def get_current_motion_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCurrentMotionProfile(CATBSTR profile)
                | 
                |     Get current Motion profile name used in controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This outer parameter contains Motion profile name.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetCurrentMotionProfile(profile)

    def get_current_obj_frame_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCurrentObjFrameProfile(CATBSTR profile)
                | 
                |     Get current ObjFrame profile name used in controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This outer parameter contains ObjFrame profile name.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetCurrentObjFrameProfile(profile)

    def get_current_tool_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCurrentToolProfile(CATBSTR profile)
                | 
                |     Get current tool profile name used in controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This outer parameter contains tool profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetCurrentToolProfile(profile)

    def get_motion_profile(self, name: str, profile: 'GenericMotionProfile') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMotionProfile(CATBSTR name,
                | GenericMotionProfile profile)
                | 
                |     Get Motion profile given name.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the Motion profile.
                |             
                |         profile
                |             This outer parameter contains interface pointer to Motion profile.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param GenericMotionProfile profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetMotionProfile(name, profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_motion_profile'
        # # vba_code = """
        # # Public Function get_motion_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.GetMotionProfile name
        # #     get_motion_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_motion_profile_count(self, count: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMotionProfileCount(long count)
                | 
                |     Get number of Motion profiles in controller.
                | 
                |     Parameters:
                | 
                |         count
                |             This outer parameter contains number of Motion profiles.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int count:
        :rtype: None
        """
        return self.rob_generic_controller.GetMotionProfileCount(count)

    def get_motion_profiles(self, profiles: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMotionProfiles(CATSafeArrayVariant profiles)
                | 
                |     Get Motion profiles list in controller.
                | 
                |     Parameters:
                | 
                |         profiles
                |             This outer parameter contains Motion profile list.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param tuple profiles:
        :rtype: None
        """
        return self.rob_generic_controller.GetMotionProfiles(profiles)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_motion_profiles'
        # # vba_code = """
        # # Public Function get_motion_profiles(rob_generic_controller)
        # #     Dim profiles (2)
        # #     rob_generic_controller.GetMotionProfiles profiles
        # #     get_motion_profiles = profiles
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_name(self, o_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oName)
                | 
                |     Retreives name of the generic controller.
                | 
                |     Parameters:
                | 
                |         name
                |             name of the controller to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str o_name:
        :rtype: None
        """
        return self.rob_generic_controller.GetName(o_name)

    def get_obj_frame_profile(self, name: str, profile: GenericObjFrameProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetObjFrameProfile(CATBSTR name,
                | GenericObjFrameProfile profile)
                | 
                |     Get ObjFrame profile given name.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the ObjFrame profile.
                |             
                |         profile
                |             This outer parameter contains interface pointer to ObjFrame
                |             profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param GenericObjFrameProfile profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetObjFrameProfile(name, profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_obj_frame_profile'
        # # vba_code = """
        # # Public Function get_obj_frame_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.GetObjFrameProfile name
        # #     get_obj_frame_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_obj_frame_profile_count(self, count: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetObjFrameProfileCount(long count)
                | 
                |     Get number of ObjFrame profiles in controller.
                | 
                |     Parameters:
                | 
                |         count
                |             This outer parameter contains number of ObjFrame profiles.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int count:
        :rtype: None
        """
        return self.rob_generic_controller.GetObjFrameProfileCount(count)

    def get_obj_frame_profiles(self, profiles: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetObjFrameProfiles(CATSafeArrayVariant profiles)
                | 
                |     Get ObjFrame profiles list in controller.
                | 
                |     Parameters:
                | 
                |         profiles
                |             This outer parameter contains ObjFrame profile list.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param tuple profiles:
        :rtype: None
        """
        return self.rob_generic_controller.GetObjFrameProfiles(profiles)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_obj_frame_profiles'
        # # vba_code = """
        # # Public Function get_obj_frame_profiles(rob_generic_controller)
        # #     Dim profiles (2)
        # #     rob_generic_controller.GetObjFrameProfiles profiles
        # #     get_obj_frame_profiles = profiles
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tool_profile(self, name: str, profile: GenericToolProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolProfile(CATBSTR name,
                | GenericToolProfile profile)
                | 
                |     Get tool profile given name.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the tool profile. 
                |         profile
                |             This outer parameter contains interface pointer to tool profile.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param GenericToolProfile profile:
        :rtype: None
        """
        return self.rob_generic_controller.GetToolProfile(name, profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tool_profile'
        # # vba_code = """
        # # Public Function get_tool_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.GetToolProfile name
        # #     get_tool_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tool_profile_count(self, count: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolProfileCount(long count)
                | 
                |     Get number of tool profiles in controller.
                | 
                |     Parameters:
                | 
                |         count
                |             This outer parameter contains number of tool profiles.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param int count:
        :rtype: None
        """
        return self.rob_generic_controller.GetToolProfileCount(count)

    def get_tool_profiles(self, profiles: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolProfiles(CATSafeArrayVariant profiles)
                | 
                |     Get tool profiles list in controller.
                | 
                |     Parameters:
                | 
                |         profiles
                |             This outer parameter contains tool profile list. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param tuple profiles:
        :rtype: None
        """
        return self.rob_generic_controller.GetToolProfiles(profiles)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tool_profiles'
        # # vba_code = """
        # # Public Function get_tool_profiles(rob_generic_controller)
        # #     Dim profiles (2)
        # #     rob_generic_controller.GetToolProfiles profiles
        # #     get_tool_profiles = profiles
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_accuracy_profile(self, name: str, flag: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasAccuracyProfile(CATBSTR name,
                | boolean flag)
                | 
                |     Check whether given tool profile exists.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the Accuracy profile.
                |             
                |         flag
                |             This outer parameter contains whether Accuracy profile exists.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param bool flag:
        :rtype: None
        """
        return self.rob_generic_controller.HasAccuracyProfile(name, flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'has_accuracy_profile'
        # # vba_code = """
        # # Public Function has_accuracy_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.HasAccuracyProfile name
        # #     has_accuracy_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_motion_profile(self, name: str, flag: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasMotionProfile(CATBSTR name,
                | boolean flag)
                | 
                |     Check whether given Motion profile exists.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the Motion profile.
                |             
                |         flag
                |             This outer parameter contains whether Motion profile exists.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param bool flag:
        :rtype: None
        """
        return self.rob_generic_controller.HasMotionProfile(name, flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'has_motion_profile'
        # # vba_code = """
        # # Public Function has_motion_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.HasMotionProfile name
        # #     has_motion_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_obj_frame_profile(self, name: str, flag: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasObjFrameProfile(CATBSTR name,
                | boolean flag)
                | 
                |     Check whether given ObjFrame profile exists.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the ObjFrame profile.
                |             
                |         flag
                |             This outer parameter contains whether ObjFrame profile exists.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param bool flag:
        :rtype: None
        """
        return self.rob_generic_controller.HasObjFrameProfile(name, flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'has_obj_frame_profile'
        # # vba_code = """
        # # Public Function has_obj_frame_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.HasObjFrameProfile name
        # #     has_obj_frame_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_tool_profile(self, name: str, flag: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub HasToolProfile(CATBSTR name,
                | boolean flag)
                | 
                |     Check whether given tool profile exists.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains name of the tool profile. 
                |         flag
                |             This outer parameter contains whether tool profile exists.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :param bool flag:
        :rtype: None
        """
        return self.rob_generic_controller.HasToolProfile(name, flag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'has_tool_profile'
        # # vba_code = """
        # # Public Function has_tool_profile(rob_generic_controller)
        # #     Dim name (2)
        # #     rob_generic_controller.HasToolProfile name
        # #     has_tool_profile = name
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_accuracy_profile(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAccuracyProfile(CATBSTR name)
                | 
                |     Remove Accuracy profile given name in controller.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains Accuracy profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :rtype: None
        """
        return self.rob_generic_controller.RemoveAccuracyProfile(name)

    def remove_motion_profile(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveMotionProfile(CATBSTR name)
                | 
                |     Remove Motion profile given name in controller.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains Motion profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :rtype: None
        """
        return self.rob_generic_controller.RemoveMotionProfile(name)

    def remove_obj_frame_profile(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveObjFrameProfile(CATBSTR name)
                | 
                |     Remove ObjFrame profile given name in controller.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains ObjFrame profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :rtype: None
        """
        return self.rob_generic_controller.RemoveObjFrameProfile(name)

    def remove_tool_profile(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveToolProfile(CATBSTR name)
                | 
                |     Remove tool profile given name in controller.
                | 
                |     Parameters:
                | 
                |         name
                |             This parameter contains tool profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :rtype: None
        """
        return self.rob_generic_controller.RemoveToolProfile(name)

    def set_current_accuracy_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentAccuracyProfile(CATBSTR profile)
                | 
                |     Make Accuracy profile with given name as current tool profile being used by
                |     controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This parameter contains Accuracy profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.SetCurrentAccuracyProfile(profile)

    def set_current_motion_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentMotionProfile(CATBSTR profile)
                | 
                |     Make Motion profile with given name as current tool profile being used by
                |     controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This parameter contains Motion profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.SetCurrentMotionProfile(profile)

    def set_current_obj_frame_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentObjFrameProfile(CATBSTR profile)
                | 
                |     Make ObjFrame profile with given name as current ObjFrame profile being
                |     used by controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This parameter contains ObjFrame profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.SetCurrentObjFrameProfile(profile)

    def set_current_tool_profile(self, profile: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentToolProfile(CATBSTR profile)
                | 
                |     Make tool profile with given name as current tool profile being used by
                |     controller.
                | 
                |     Parameters:
                | 
                |         profile
                |             This parameter contains tool profile name. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str profile:
        :rtype: None
        """
        return self.rob_generic_controller.SetCurrentToolProfile(profile)

    def set_name(self, name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR name)
                | 
                |     Set name of the generic controller.
                | 
                |     Parameters:
                | 
                |         name
                |             name of the controller to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str name:
        :rtype: None
        """
        return self.rob_generic_controller.SetName(name)

    def __repr__(self):
        return f'RobGenericController(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.analysis_interfaces.analysis_images import AnalysisImages
from pycatia.analysis_interfaces.analysis_local_entities import AnalysisLocalEntities
from pycatia.analysis_interfaces.analysis_supports import AnalysisSupports
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.constraint import Constraint
from pycatia.mec_mod_interfaces.part import Part
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.analysis_interfaces.basic_components import BasicComponents


class AnalysisEntity(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisEntity
                | 
                | Represent the analysis entity object.
                | This class provides services to describe a analysis entity. It represents some
                | preprocessing activities.
                | It agregates descriptive sub-entities named Basic Components, and Analysis
                | Supports.
                | The basic component represent the physical data and the support the
                | localisation.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_entity = com_object

    @property
    def analysis_images(self) -> AnalysisImages:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisImages() As AnalysisImages (Read Only)
                | 
                |     Returns the analysis images collection associated with an analysis
                |     entity.
                | 
                |     Example:
                |         This example retrieves analysisimages collection .
                | 
                |          Dim MyEntity As AnalysisEntity
                |          Dim analysisimages As AnalysisImages
                |          Set analysisimages = MyEntity.AnalysisImages

        :rtype: AnalysisImages
        """

        return AnalysisImages(self.analysis_entity.AnalysisImages)

    @property
    def analysis_local_entities(self) -> AnalysisLocalEntities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisLocalEntities() As AnalysisLocalEntities (Read
                | Only)
                | 
                |     Returns the analysis local entity collection associated with an analysis
                |     entity.
                | 
                |     Example:
                |         This example retrieves analysislocalEntity collection
                |         .
                | 
                |          Dim MyEntity As AnalysisEntity
                |          Dim analysislocalEntity As AnalysisLocalEntities
                |          Set analysislocalEntity = MyEntity.AnalysisLocalEntities

        :rtype: AnalysisLocalEntities
        """

        return AnalysisLocalEntities(self.analysis_entity.AnalysisLocalEntities)

    @property
    def analysis_supports(self) -> AnalysisSupports:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisSupports() As AnalysisSupports (Read Only)
                | 
                |     Returns the list of Analysis Supports. The support defines the area on
                |     which the analysis is applied on.

        :rtype: AnalysisSupports
        """

        return AnalysisSupports(self.analysis_entity.AnalysisSupports)

    @property
    def basic_components(self) -> 'BasicComponents':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BasicComponents() As BasicComponents (Read Only)
                | 
                |     Returns the basic components collection associated with an analysis
                |     entity.
                | 
                |     Example:
                |         This example retrieves basiccomponents collection .
                | 
                |          Dim MyEntity As AnalysisEntity
                |          Dim basiccomponents As BasicComponents 
                |          Set basiccomponents = MyEntity.BasicComponents

        :rtype: BasicComponents
        """

        from pycatia.analysis_interfaces.basic_components import BasicComponents
        return BasicComponents(self.analysis_entity.BasicComponents)

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the analysis entity.
                | 
                |     Example:
                |         The following example returns TypeofEntity of
                |         MyEntity.
                | 
                |          Dim MyEntity As AnalysisEntity
                |          Dim TypeofEntity As CATBSTR
                |          Set TypeofEntity = MyEntity.Type

        :rtype: str
        """

        return self.analysis_entity.Type

    def add_support_from_constraint(self, i_constraint_product: Product, i_constraint: Constraint) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromConstraint(Product iConstraintProduct,
                | Constraint iConstraint)
                | 
                |     Creates a new support and add it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iConstraintProduct
                |             the CATIA Product of the Constraint.
                |         iConstraint
                |             the CATIA Constraint that represent the object to
                |             linked.
                | 
                |     See also:
                |         Reference, Part

        :param Product i_constraint_product:
        :param Constraint i_constraint:
        :rtype: None
        """
        return self.analysis_entity.AddSupportFromConstraint(i_constraint_product.com_object, i_constraint.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_constraint'
        # # vba_code = """
        # # Public Function add_support_from_constraint(analysis_entity)
        # #     Dim iConstraintProduct (2)
        # #     analysis_entity.AddSupportFromConstraint iConstraintProduct
        # #     add_support_from_constraint = iConstraintProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_part(self, i_part_product: Product, i_part: Part) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPart(Product iPartProduct,
                | Part iPart)
                | 
                |     Creates a new support and add it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iPartProduct
                |             the CATIA Product of the part.
                |         iPart
                |             the CATIA Part that represent the object to
                |             linked.
                | 
                |     See also:
                |         Reference, Part

        :param Product i_part_product:
        :param Part i_part:
        :rtype: None
        """
        return self.analysis_entity.AddSupportFromPart(i_part_product.com_object, i_part.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_part'
        # # vba_code = """
        # # Public Function add_support_from_part(analysis_entity)
        # #     Dim iPartProduct (2)
        # #     analysis_entity.AddSupportFromPart iPartProduct
        # #     add_support_from_part = iPartProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_product(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromProduct(Product iProduct,
                | Reference iSupport)
                | 
                |     Creates a new support and add it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iSupport
                |             the CATIA Reference that represent the object to
                |             linked.
                | 
                |     See also:
                |         Reference, Product

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.analysis_entity.AddSupportFromProduct(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_product'
        # # vba_code = """
        # # Public Function add_support_from_product(analysis_entity)
        # #     Dim iProduct (2)
        # #     analysis_entity.AddSupportFromProduct iProduct
        # #     add_support_from_product = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Creates a new support and add it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             the CATIA Product that represent the object to
                |             linked.
                |         iPublication
                |             the CATIA Publication that represent the object to
                |             linked.
                | 
                |     See also:
                |         Publication, Product

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.analysis_entity.AddSupportFromPublication(i_product.com_object, i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(analysis_entity)
        # #     Dim iProduct (2)
        # #     analysis_entity.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Creates a new support and add it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iReference
                |             the CATIA Reference that represent the object to linked. This
                |             identification, may locate the instance of the
                |             object
                |         iSupport
                |             the CATIA Reference that represent the object to
                |             linked.
                | 
                |     See also:
                |         Reference

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.analysis_entity.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(analysis_entity)
        # #     Dim iReference (2)
        # #     analysis_entity.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_reference(self, i_component: str, i_label: str, i_line_index: int, i_column_index: int,
                      i_layer_index: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetReference(CATBSTR iComponent,
                | CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex) As Reference
                | 
                |     Returns the reference corresponding to the given
                |     component.
                | 
                |     Parameters:
                | 
                |         iComponent
                |             The identifier if the basic component.
                |         iLabel
                |             The label of the block containing the value.
                |         iLineIndex
                |             The line index of the value.
                |         iColumnIndex
                |             The column index of the value.
                |         iLayerIndex
                |             The layer index of the value.

        :param str i_component:
        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :rtype: Reference
        """
        return Reference(
            self.analysis_entity.GetReference(i_component, i_label, i_line_index, i_column_index, i_layer_index))

    def get_value(self, i_component: str, i_label: str, i_line_index: int, i_column_index: int,
                  i_layer_index: int) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetValue(CATBSTR iComponent,
                | CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex) As CATVariant
                | 
                |     Returns the value corresponding to the given component.
                | 
                |     Parameters:
                | 
                |         iComponent
                |             The identifier if the basic component.
                |         iLabel
                |             The label of the block containing the value.
                |         iLineIndex
                |             The line index of the value.
                |         iColumnIndex
                |             The column index of the value.
                |         iLayerIndex
                |             The layer index of the value.

        :param str i_component:
        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :rtype: cat_variant
        """
        return self.analysis_entity.GetValue(i_component, i_label, i_line_index, i_column_index, i_layer_index)

    def set_reference(
            self,
            i_component: str,
            i_label: str,
            i_line_index: int,
            i_column_index: int,
            i_layer_index: int,
            i_value: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetReference(CATBSTR iComponent,
                | CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex,
                | Reference iValue)
                | 
                |     Sets the reference corresponding to the given component.
                | 
                |     Parameters:
                | 
                |         iComponent
                |             The identifier if the basic component.
                |         iLabel
                |             The label of the block containing the value.
                |         iLineIndex
                |             The line index of the value.
                |         iColumnIndex
                |             The column index of the value.
                |         iLayerIndex
                |             The layer index of the value.
                |             If the the component has a single value, assign 0 to the 3
                |             parameters.

        :param str i_component:
        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :param Reference i_value:
        :rtype: None
        """
        return self.analysis_entity.SetReference(
            i_component,
            i_label,
            i_line_index,
            i_column_index,
            i_layer_index,
            i_value.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_reference'
        # # vba_code = """
        # # Public Function set_reference(analysis_entity)
        # #     Dim iComponent (2)
        # #     analysis_entity.SetReference iComponent
        # #     set_reference = iComponent
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_value(
            self,
            i_component: str,
            i_label: str,
            i_line_index: int,
            i_column_index: int,
            i_layer_index: int,
            i_value: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetValue(CATBSTR iComponent,
                | CATBSTR iLabel,
                | long iLineIndex,
                | long iColumnIndex,
                | long iLayerIndex,
                | CATVariant iValue)
                | 
                |     Sets the value corresponding to the given component.
                | 
                |     Parameters:
                | 
                |         iComponent
                |             The identifier if the basic component.
                |         iLabel
                |             The label of the block containing the value.
                |         iLineIndex
                |             The line index of the value.
                |         iColumnIndex
                |             The column index of the value.
                |         iLayerIndex
                |             The layer index of the value.
                |             If the the component has a single value, assign 0 to the 3
                |             parameters. This example create ThisAnalysisEntity in the analysisEntities
                |             collection
                |             The entity to create is supposed to be a pressure defined in a load
                |             set. We
                |             will valuate the basic component that contain the pressure data
                |             "SAMPressureMag".
                | 
                |              Dim analysisEntities As CATIAAnalysisEntities
                |              Dim ThisAnalysisEntity As AnalysisEntity
                |              Set ThisAnalysisEntity = analysisEntities.Add("SAMPressure")
                |              ThisAnalysisEntity.SetValue("SAMPressureMag","
                |              ",0,0,0,100)

        :param str i_component:
        :param str i_label:
        :param int i_line_index:
        :param int i_column_index:
        :param int i_layer_index:
        :param cat_variant i_value:
        :rtype: None
        """
        return self.analysis_entity.SetValue(
            i_component,
            i_label,
            i_line_index,
            i_column_index,
            i_layer_index,
            i_value
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_value'
        # # vba_code = """
        # # Public Function set_value(analysis_entity)
        # #     Dim iComponent (2)
        # #     analysis_entity.SetValue iComponent
        # #     set_value = iComponent
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisEntity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_boundary_elem import SchBoundaryElem
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchGRRZone(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRRZone
                | 
                | Manage the graphical representation of a schematic zone.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr_zone = com_object

    def add_boundary_element(self, i_zone_bndy_to_add: SchBoundaryElem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddBoundaryElement(SchBoundaryElem iZoneBndyToAdd)
                | 
                |     Add a boundary element to the zone.
                | 
                |     Parameters:
                | 
                |         iZoneBndy
                |             The geometric boundary elements to be added. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRZone
                |          Dim objArg1 As SchBoundaryElem
                |           ...
                |          objThisIntf.AddBoundaryElementobjArg1

        :param SchBoundaryElem i_zone_bndy_to_add:
        :rtype: None
        """
        return self.sch_grr_zone.AddBoundaryElement(i_zone_bndy_to_add.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_boundary_element'
        # # vba_code = """
        # # Public Function add_boundary_element(sch_grr_zone)
        # #     Dim iZoneBndyToAdd (2)
        # #     sch_grr_zone.AddBoundaryElement iZoneBndyToAdd
        # #     add_boundary_element = iZoneBndyToAdd
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_boundary_valid(self, b_is_valid: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsBoundaryValid(boolean BIsValid)
                | 
                |     Check whether the boundary of this zone graphical representation is
                |     valid.
                | 
                |     Parameters:
                | 
                |         oLZoneBndy
                |             Set to TRUE if the boundary is a closed polygon 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRZone
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.IsBoundaryValidbVar1

        :param bool b_is_valid:
        :rtype: None
        """
        return self.sch_grr_zone.IsBoundaryValid(b_is_valid)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_boundary_valid'
        # # vba_code = """
        # # Public Function is_boundary_valid(sch_grr_zone)
        # #     Dim BIsValid (2)
        # #     sch_grr_zone.IsBoundaryValid BIsValid
        # #     is_boundary_valid = BIsValid
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_boundary_elements(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListBoundaryElements() As SchListOfObjects
                | 
                |     List all boundary elements of this zone graphical
                |     representation.
                | 
                |     Parameters:
                | 
                |         oLZoneBndy
                |             List of geometric boundaries of this zone graphical representation
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchGRRZone
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListBoundaryElements

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_grr_zone.ListBoundaryElements())

    def remove_boundary_element(self, i_zone_bndy_to_remove: SchBoundaryElem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveBoundaryElement(SchBoundaryElem
                | iZoneBndyToRemove)
                | 
                |     Remove a boundary element to the zone.
                | 
                |     Parameters:
                | 
                |         iZoneBndy
                |             The geometric boundary elements to be added. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRZone
                |          Dim objArg1 As SchBoundaryElem
                |           ...
                |          objThisIntf.RemoveBoundaryElementobjArg1

        :param SchBoundaryElem i_zone_bndy_to_remove:
        :rtype: None
        """
        return self.sch_grr_zone.RemoveBoundaryElement(i_zone_bndy_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_boundary_element'
        # # vba_code = """
        # # Public Function remove_boundary_element(sch_grr_zone)
        # #     Dim iZoneBndyToRemove (2)
        # #     sch_grr_zone.RemoveBoundaryElement iZoneBndyToRemove
        # #     remove_boundary_element = iZoneBndyToRemove
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchGRRZone(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchFrameInfo(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchFrameInfo
                | 
                | Manage the background view of a schematic viewer.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_frame_info = com_object

    def get_label_code(self, o_label: str, i_b_horiz: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLabelCode(CATBSTR oLabel,
                | boolean iBHoriz)
                | 
                |     Get the frame label code.
                | 
                |     Parameters:
                | 
                |         oLabel
                |             Label code. 
                |         iBHoriz
                |             If TRUE, then the labels are for horizontal spacing, else, they are
                |             for vertical spacing. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchFrameInfo
                |          Dim strVar1 As String
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.GetLabelCodestrVar1,bVar2

        :param str o_label:
        :param bool i_b_horiz:
        :rtype: None
        """
        return self.sch_frame_info.GetLabelCode(o_label, i_b_horiz)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_label_code'
        # # vba_code = """
        # # Public Function get_label_code(sch_frame_info)
        # #     Dim oLabel (2)
        # #     sch_frame_info.GetLabelCode oLabel
        # #     get_label_code = oLabel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin_corner_code(self, o_origin_corner: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOriginCornerCode(CATBSTR oOriginCorner)
                | 
                |     Get the frame origin corner code.
                | 
                |     Parameters:
                | 
                |         oOriginCorner
                |             Origin corner code. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchFrameInfo
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.GetOriginCornerCodestrVar1

        :param str o_origin_corner:
        :rtype: None
        """
        return self.sch_frame_info.GetOriginCornerCode(o_origin_corner)

    def get_spacing_code(self, o_spacing: str, i_b_horiz: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSpacingCode(CATBSTR oSpacing,
                | boolean iBHoriz)
                | 
                |     Get the frame spacing code.
                | 
                |     Parameters:
                | 
                |         oSpacing
                |             Spacing code. 
                |         iBHoriz
                |             If TRUE, then the spacing is for horizontal, else, the spacing is
                |             for vertical. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchFrameInfo
                |          Dim strVar1 As String
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.GetSpacingCodestrVar1,bVar2

        :param str o_spacing:
        :param bool i_b_horiz:
        :rtype: None
        """
        return self.sch_frame_info.GetSpacingCode(o_spacing, i_b_horiz)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_spacing_code'
        # # vba_code = """
        # # Public Function get_spacing_code(sch_frame_info)
        # #     Dim oSpacing (2)
        # #     sch_frame_info.GetSpacingCode oSpacing
        # #     get_spacing_code = oSpacing
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_label_code(self, i_label: str, i_b_horiz: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLabelCode(CATBSTR iLabel,
                | boolean iBHoriz)
                | 
                |     Set the frame label code.
                | 
                |     Parameters:
                | 
                |         iLabel
                |             Label code. 
                |         iBHoriz
                |             If TRUE, then the labels are for horizontal spacing, else, they are
                |             for vertical spacing. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchFrameInfo
                |          Dim strVar1 As String
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.SetLabelCodestrVar1,bVar2

        :param str i_label:
        :param bool i_b_horiz:
        :rtype: None
        """
        return self.sch_frame_info.SetLabelCode(i_label, i_b_horiz)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_label_code'
        # # vba_code = """
        # # Public Function set_label_code(sch_frame_info)
        # #     Dim iLabel (2)
        # #     sch_frame_info.SetLabelCode iLabel
        # #     set_label_code = iLabel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_origin_corner_code(self, i_origin_corner: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOriginCornerCode(CATBSTR iOriginCorner)
                | 
                |     Set the frame origin corner code.
                | 
                |     Parameters:
                | 
                |         iOriginCorner
                |             Origin corner code. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchFrameInfo
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.SetOriginCornerCodestrVar1

        :param str i_origin_corner:
        :rtype: None
        """
        return self.sch_frame_info.SetOriginCornerCode(i_origin_corner)

    def set_spacing_code(self, i_spacing: str, i_b_horiz: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpacingCode(CATBSTR iSpacing,
                | boolean iBHoriz)
                | 
                |     Set the frame spacing code.
                | 
                |     Parameters:
                | 
                |         iSpacing
                |             Spacing code. 
                |         iBHoriz
                |             If TRUE, then the spacing is for horizontal, else, the spacing is
                |             for vertical. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchFrameInfo
                |          Dim strVar1 As String
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.SetSpacingCodestrVar1,bVar2

        :param str i_spacing:
        :param bool i_b_horiz:
        :rtype: None
        """
        return self.sch_frame_info.SetSpacingCode(i_spacing, i_b_horiz)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_spacing_code'
        # # vba_code = """
        # # Public Function set_spacing_code(sch_frame_info)
        # #     Dim iSpacing (2)
        # #     sch_frame_info.SetSpacingCode iSpacing
        # #     set_spacing_code = iSpacing
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchFrameInfo(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_history_output_request import ABQHistoryOutputRequest
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQHistoryOutputRequests(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQHistoryOutputRequests
                | 
                | The collection of Abaqus history output request (ABQHistoryOutputRequest)
                | objects attached to an
                | ABQGeneralStaticStep, an ABQHeatTransferStep, or an ABQExplicitDynamicsStep
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQHistoryOutputRequest)
        self.abq_history_output_requests = com_object

    def add(self) -> ABQHistoryOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As ABQHistoryOutputRequest
                | 
                |     Creates a new Abaqus history output request and adds it to the collection
                |     of Abaqus history output requests.
                | 
                |     Returns:
                |         oHistoryOutputRequest The Abaqus history output request object that was
                |         created. 
                |     Example:
                |         The following example creates a history output request in the
                |         ABQHistoryOutputRequests collection:
                | 
                |          Dim abqHistoryOutputRequests As
                |          ABQHistoryOutputRequests
                |          Set abqHistoryOutputRequests = generalstaticstep.HistoryOutputRequests
                |          Dim abqHistoryOutputRequest As
                |          ABQHistoryOutputRequest
                |          Set abqHistoryOutputRequest =  abqHistoryOutputRequests.Add()

        :rtype: ABQHistoryOutputRequest
        """
        return ABQHistoryOutputRequest(self.abq_history_output_requests.Add())

    def item(self, i_index: cat_variant) -> ABQHistoryOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQHistoryOutputRequest
                | 
                |     Returns an Abaqus history output request using its index or its name from
                |     the ABQHistoryOutputRequests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus history output request to
                |             retrieve from the collection of Abaqus history output requests. If the index is
                |             a number, it specifies the rank of the Abaqus history output request in the
                |             collection. The index of the first Abaqus history output request in the
                |             collection is 1, and the index of the last history output request is Count. If
                |             the index is a string, it specifies the name you assigned to the history output
                |             request using the CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQHistoryOutputRequest.

        :param cat_variant i_index:
        :rtype: ABQHistoryOutputRequest
        """
        return ABQHistoryOutputRequest(self.abq_history_output_requests.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus history output request using its index or its name from
                |     the history output requests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the history output request to retrieve
                |             from the collection of history output requests. As a numeric, this index is the
                |             rank of the history output request in the collection. The index of the first
                |             history output request in the collection is 1, and the index of the last
                |             history output request is Count. As a string, it is the name you assigned to
                |             the history output request using the CATIABase::Name
                |             property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_history_output_requests.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_history_output_requests)
        # #     Dim iIndex (2)
        # #     abq_history_output_requests.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQHistoryOutputRequests(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.kinematics_interfaces.joint import Joint
from pycatia.system_interfaces.any_object import AnyObject


class DeviceJointRelations(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DeviceJointRelations
                | 
                | INTERFACE : DNBIADeviceJointRelations
                | DESCRIPTION This interface allows to assign symbolic kinematic relations to
                | Mechanism joints
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.device_joint_relations = com_object

    def get_joint_relation_expression(self, joint: Joint, expr: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetJointRelationExpression(Joint joint,
                | CATBSTR expr)
                | 
                |     Get Kin expression of the given Joint.
                | 
                |     Parameters:
                | 
                |         joint
                |             This input parameter specify CATIAJoint interface.
                |             
                |         expr
                |             This out parameter contains kin expression assigned to 'joint'.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param Joint joint:
        :param str expr:
        :rtype: None
        """
        return self.device_joint_relations.GetJointRelationExpression(joint.com_object, expr)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_joint_relation_expression'
        # # vba_code = """
        # # Public Function get_joint_relation_expression(device_joint_relations)
        # #     Dim joint (2)
        # #     device_joint_relations.GetJointRelationExpression joint
        # #     get_joint_relation_expression = joint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_joint_relation_expression(self, joint: Joint, expr: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJointRelationExpression(Joint joint,
                | CATBSTR expr)
                | 
                |     Set Kin expression for the given Joint.
                | 
                |     Parameters:
                | 
                |         joint
                |             This input parameter specifies CATIAJoint interface.
                |             
                |         profile
                |             This input parameter contains kin expression to be assigned for
                |             'joint'. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param Joint joint:
        :param str expr:
        :rtype: None
        """
        return self.device_joint_relations.SetJointRelationExpression(joint.com_object, expr)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_joint_relation_expression'
        # # vba_code = """
        # # Public Function set_joint_relation_expression(device_joint_relations)
        # #     Dim joint (2)
        # #     device_joint_relations.SetJointRelationExpression joint
        # #     set_joint_relation_expression = joint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_user_variable_expr(self, user_expr: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUserVariableExpr(CATBSTR user_expr)
                | 
                |     Add the user-variable expression to the mechanism
                | 
                |     Parameters:
                | 
                |         user_expr
                |             This input parameter is an user-variable expression.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param str user_expr:
        :rtype: None
        """
        return self.device_joint_relations.SetUserVariableExpr(user_expr)

    def __repr__(self):
        return f'DeviceJointRelations(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchBoundaryElem(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchBoundaryElem
                | 
                | Manage a boundary element of a schematic zone.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_boundary_elem = com_object

    def get_boundary_points(self, o_l_db_pts: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetBoundaryPoints(SchListOfDoubles oLDbPts)
                | 
                |     Get the definition points (segments end points) of one side of the
                |     boundary. If the side is a curve, these points are the end points of the chords
                |     approximating the curve.
                | 
                |     Parameters:
                | 
                |         oLDbPts
                |             A list of X-Y coordinates of the points. 2 doubles per point.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchBoundaryElem
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetBoundaryPointsobjArg1

        :param SchListOfDoubles o_l_db_pts:
        :rtype: None
        """
        return self.sch_boundary_elem.GetBoundaryPoints(o_l_db_pts.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_boundary_points'
        # # vba_code = """
        # # Public Function get_boundary_points(sch_boundary_elem)
        # #     Dim oLDbPts (2)
        # #     sch_boundary_elem.GetBoundaryPoints oLDbPts
        # #     get_boundary_points = oLDbPts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_end_points(self, o_l_db4_pts: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetEndPoints(SchListOfDoubles oLDb4Pts)
                | 
                |     Get the end points (segments end points) of one side of the
                |     boundary.
                | 
                |     Parameters:
                | 
                |         oLDb4Pts
                |             An array of 4 doubles. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchBoundaryElem
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetEndPointsobjArg1

        :param SchListOfDoubles o_l_db4_pts:
        :rtype: None
        """
        return self.sch_boundary_elem.GetEndPoints(o_l_db4_pts.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_end_points'
        # # vba_code = """
        # # Public Function get_end_points(sch_boundary_elem)
        # #     Dim oLDb4Pts (2)
        # #     sch_boundary_elem.GetEndPoints oLDb4Pts
        # #     get_end_points = oLDb4Pts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_grr_zone_owners(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListGRRZoneOwners() As SchListOfObjects
                | 
                |     Get the list of owners of this zone.
                | 
                |     Parameters:
                | 
                |         oLGRRZoneOwners
                |             A list of GRRZone which has included this boundary element.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchBoundaryElem
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListGRRZoneOwners

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_boundary_elem.ListGRRZoneOwners())

    def __repr__(self):
        return f'SchBoundaryElem(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class PSPStretchableData(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspStretchableData
                | 
                | Represents the PspStretchableData object.
                | Role: To access the technological data on stretchable objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_stretchable_data = com_object

    def list_bend_data(self) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListBendData() As PspListOfDoubles
                | 
                |     Returns the bend radii.
                | 
                |     Returns:
                |         List of bend radius.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspStretchableData  
                |          Dim objArg1 As PspListOfDoubles
                |           ...
                |          Set objArg1 = objThisIntf.ListBendData

        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_stretchable_data.ListBendData())

    def list_definition_points(self, i_rel_axis: Product) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListDefinitionPoints(Product iRelAxis) As
                | PspListOfDoubles
                | 
                |     Returns the points defining the object.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             The relative axis object (Nothing means relative to parent).
                |             
                | 
                |     Returns:
                |         List of points defining object. A list of X-Y-Z coordinates of the
                |         points. 3 doubles per point.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspStretchableData
                |          Dim objArg1 As Product
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.ListDefinitionPoints (objArg1)

        :param Product i_rel_axis:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_stretchable_data.ListDefinitionPoints(i_rel_axis.com_object))

    def __repr__(self):
        return f'PSPStretchableData(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_member import SFMMember
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class SFMMember2Points(SFMMember):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                            CATStrFunctionalInterfaces.SfmMember
                |                                 SfmMember2Points
                | 
                | Interface to manage Member created with one curve and a reference
                | surface.
                | Role: To manage member created with one curve and a reference
                | surface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_member2_points = com_object

    @property
    def end_point_on_crv_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPointOnCrvCurve() As Reference

        :rtype: Reference
        """

        return Reference(self.sfm_member2_points.EndPointOnCrvCurve)

    @end_point_on_crv_curve.setter
    def end_point_on_crv_curve(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member2_points.EndPointOnCrvCurve = value.com_object

    @property
    def end_point_on_crv_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPointOnCrvMode() As boolean

        :rtype: bool
        """

        return self.sfm_member2_points.EndPointOnCrvMode

    @end_point_on_crv_mode.setter
    def end_point_on_crv_mode(self, value: bool):
        """
        :param bool value:
        """

        self.sfm_member2_points.EndPointOnCrvMode = value

    @property
    def end_point_on_crv_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPointOnCrvOffset() As double

        :rtype: float
        """

        return self.sfm_member2_points.EndPointOnCrvOffset

    @end_point_on_crv_offset.setter
    def end_point_on_crv_offset(self, value: float):
        """
        :param float value:
        """

        self.sfm_member2_points.EndPointOnCrvOffset = value

    @property
    def end_point_on_crv_offset_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPointOnCrvOffsetParam() As Length (Read Only)

        :rtype: Length
        """

        return Length(self.sfm_member2_points.EndPointOnCrvOffsetParam)

    @property
    def end_point_on_crv_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPointOnCrvOrientation() As long

        :rtype: int
        """

        return self.sfm_member2_points.EndPointOnCrvOrientation

    @end_point_on_crv_orientation.setter
    def end_point_on_crv_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_member2_points.EndPointOnCrvOrientation = value

    @property
    def end_point_spec(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndPointSpec() As Reference

        :rtype: Reference
        """

        return Reference(self.sfm_member2_points.EndPointSpec)

    @end_point_spec.setter
    def end_point_spec(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member2_points.EndPointSpec = value.com_object

    @property
    def start_point_on_crv_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartPointOnCrvCurve() As Reference
                | 
                |     Returns or sets the point on curve information: curve, ratio or length
                |     mode, offset and orientation.
                | 
                |     Example:
                |         This example retrieves in Curve the supporting curve for the
                |         SfmMember2Points feature.
                | 
                |          Dim Curve As Reference
                |          Set Curve = SfmMember2Points.StartPointOnCrvCurve

        :rtype: Reference
        """

        return Reference(self.sfm_member2_points.StartPointOnCrvCurve)

    @start_point_on_crv_curve.setter
    def start_point_on_crv_curve(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member2_points.StartPointOnCrvCurve = value.com_object

    @property
    def start_point_on_crv_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartPointOnCrvMode() As boolean

        :rtype: bool
        """

        return self.sfm_member2_points.StartPointOnCrvMode

    @start_point_on_crv_mode.setter
    def start_point_on_crv_mode(self, value: bool):
        """
        :param bool value:
        """

        self.sfm_member2_points.StartPointOnCrvMode = value

    @property
    def start_point_on_crv_offset(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartPointOnCrvOffset() As double

        :rtype: float
        """

        return self.sfm_member2_points.StartPointOnCrvOffset

    @start_point_on_crv_offset.setter
    def start_point_on_crv_offset(self, value: float):
        """
        :param float value:
        """

        self.sfm_member2_points.StartPointOnCrvOffset = value

    @property
    def start_point_on_crv_offset_param(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartPointOnCrvOffsetParam() As Length (Read Only)

        :rtype: Length
        """

        return Length(self.sfm_member2_points.StartPointOnCrvOffsetParam)

    @property
    def start_point_on_crv_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartPointOnCrvOrientation() As long

        :rtype: int
        """

        return self.sfm_member2_points.StartPointOnCrvOrientation

    @start_point_on_crv_orientation.setter
    def start_point_on_crv_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_member2_points.StartPointOnCrvOrientation = value

    @property
    def start_point_spec(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartPointSpec() As Reference
                | 
                |     Returns or sets the point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in Point the supporting curve for the
                |         SfmMember2Points feature.
                | 
                |          Dim Point As Reference
                |          Set Point = SfmMember2Points.StartPointSpec

        :rtype: Reference
        """

        return Reference(self.sfm_member2_points.StartPointSpec)

    @start_point_spec.setter
    def start_point_spec(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member2_points.StartPointSpec = value.com_object

    def invert_end_point_on_crv_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InvertEndPointOnCrvOrientation()

        :rtype: None
        """
        return self.sfm_member2_points.InvertEndPointOnCrvOrientation()

    def invert_start_point_on_crv_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InvertStartPointOnCrvOrientation()
                | 
                |     Inverts the orientation of the offset for an extremity
                |     point.
                | 
                |     Example:
                |         This example inverts the orientation of the start point on curve
                |         extremity of the SfmMember2Points feature.
                | 
                |          SfmMember2Points.InvertStartPointOnCrvOrientation

        :rtype: None
        """
        return self.sfm_member2_points.InvertStartPointOnCrvOrientation()

    def __repr__(self):
        return f'SFMMember2Points(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.product_structure_interfaces.product import Product


class ElectricalSchematicObject(Product):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ProductStructureInterfaces.Product
                |                         ElecSchematicObject
                | 
                | Represents the electrical schematic objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.elec_schematic_object = com_object

    @property
    def connected_elec_sch_objects(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectedElecSchObjects() As SchListOfObjects (Read
                | Only)
                | 
                |     This method returns the collection of Electrical Schematic Connected
                |     Objects.

        :rtype: SchListOfObjects
        """

        return SchListOfObjects(self.elec_schematic_object.ConnectedElecSchObjects)

    @property
    def elec_schematic_children(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ElecSchematicChildren() As SchListOfObjects (Read
                | Only)
                | 
                |     This method returns the collection of Electrical Schematic Object's
                |     Children (component in Pipe Line, Assembly).

        :rtype: SchListOfObjects
        """

        return SchListOfObjects(self.elec_schematic_object.ElecSchematicChildren)

    @property
    def elec_schematic_parent(self) -> 'ElectricalSchematicObject':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ElecSchematicParent() As ElecSchematicObject (Read
                | Only)
                | 
                |     This method returns the electrical schematic parent.

        :rtype: ElecSchematicObject
        """

        return ElectricalSchematicObject(self.elec_schematic_object.ElecSchematicParent)

    @property
    def is_space_reserved(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsSpaceReserved() As boolean (Read Only)
                | 
                |     Defines if the electrical schematic object has a reservation box in 3D
                |     world

        :rtype: bool
        """

        return self.elec_schematic_object.IsSpaceReserved

    @property
    def root_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RootType() As CATBSTR (Read Only)
                | 
                |     Returns the Electrical Schematic Object's Root Type (Equipment, Signal,
                |     Bundle, Wire).

        :rtype: str
        """

        return self.elec_schematic_object.RootType

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the Electrical Schematic Object's Type (Alternator, Signal, Bundle,
                |     Wire, ...).

        :rtype: str
        """

        return self.elec_schematic_object.Type

    def get_pin_attribute(self, i_connected_object: 'ElectricalSchematicObject', i_attr_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPinAttribute(ElecSchematicObject iConnectedObject,
                | CATBSTR iAttrName) As CATBSTR
                | 
                |     Get the value of an attribute of the pin which connects this and the
                |     specified object.

        :param ElecSchematicObject i_connected_object:
        :param str i_attr_name:
        :rtype: str
        """
        return self.elec_schematic_object.GetPinAttribute(i_connected_object.com_object, i_attr_name)

    def __repr__(self):
        return f'ElectricalSchematicObject(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.move import Move
from pycatia.in_interfaces.position import Position
from pycatia.system_interfaces.any_object import AnyObject


class SceneProductData(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SceneProductData
                | 
                | The interface to access a CATIASceneProduct
                | 
                | Using this prefered syntax will enable mkdoc to document your
                | class.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.scene_product_data = com_object

    @property
    def activation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Activation() As boolean
                | 
                |     Returns / Set the scene product's activation state.
                | 
                |     Example:
                | 
                |              This example retrieves the activation state of the scenePrd
                |              SceneProductData.
                |
                |             IsActivated = scenePrd.Hidden

        :rtype: bool
        """

        return self.scene_product_data.Activation

    @activation.setter
    def activation(self, value: bool):
        """
        :param bool value:
        """

        self.scene_product_data.Activation = value

    @property
    def hidden(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Hidden() As boolean
                | 
                |     Returns / Set the scene product's hide/show mode.
                | 
                |     Example:
                | 
                |              This example retrieves the hide/show mode of the scenePrd
                |              SceneProductData.
                |
                |             IsHidden = scenePrd.Hidden

        :rtype: bool
        """

        return self.scene_product_data.Hidden

    @hidden.setter
    def hidden(self, value: bool):
        """
        :param bool value:
        """

        self.scene_product_data.Hidden = value

    @property
    def move(self) -> Move:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Move() As Move (Read Only)
                | 
                |     Returns the scene product's move object. It aggregates a movable object to
                |     which you can apply a move transformation by means of an isometry matrix. It
                |     moves your product shape representation according to this
                |     isometry.
                | 
                |     Example:
                | 
                |              This example retrieves the EngineMove move
                |             in the scenePrd SceneProductData.
                |
                |             Dim EngineMove As Move
                |             Set EngineMove = scenePrd.GetMove

        :rtype: Move
        """

        return Move(self.scene_product_data.Move)

    @property
    def position(self) -> Position:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Position() As Position (Read Only)
                | 
                |     Returns the scene product's position object. The position object is the
                |     object aggregated by the SceneProductData object that holds the position of the
                |     master shape representation in the space in scene.
                | 
                |     Example:
                | 
                |              This example retrieves the EnginePosition
                |              position
                |             in the scenePrd SceneProductData.
                |
                |             Dim EnginePosition As Position
                |             Set EnginePosition = scenePrd.GetPosition

        :rtype: Position
        """

        return Position(self.scene_product_data.Position)

    def get_real_colour(self, o_red: int, o_green: int, o_blue: int, o_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRealColor(long oRed,
                | long oGreen,
                | long oBlue,
                | long oInheritance)
                | 
                |     Returns / Set the scene product's color and inheritance.
                | 
                |     Parameters:
                | 
                |         iRed
                |             A value between 0 and 255 
                |         iGreen
                |             A value between 0 and 255 
                |         iBlue
                |             A value between 0 and 255 
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |              This example retrieves the activation state of the scenePrd
                |              SceneProductData.
                |
                |         Dim r, g, b, inh
                |             scenePrd.GetRealColor r, g, b, inh

        :param int o_red:
        :param int o_green:
        :param int o_blue:
        :param int o_inheritance:
        :rtype: None
        """
        return self.scene_product_data.GetRealColor(o_red, o_green, o_blue, o_inheritance)

    def get_real_transparency(self, o_transparency: int, o_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetRealTransparency(long oTransparency,
                | long oInheritance)
                | 
                |     Returns the scene product's Transparency and inheritance.
                | 
                |     Parameters:
                | 
                |         oTransparency
                |             A value between 0 and 255 
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |              This example retrieves the transparency of the scenePrd
                |              SceneProductData.
                |
                |         Dim  trans, inh
                |             scenePrd.GetRealTransparency trans, inh

        :param int o_transparency:
        :param int o_inheritance:
        :rtype: None
        """
        return self.scene_product_data.GetRealTransparency(o_transparency, o_inheritance)

    def set_real_colour(self, i_red: int, i_green: int, i_blue: int, i_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRealColor(long iRed,
                | long iGreen,
                | long iBlue,
                | long iInheritance)
                | 
                |     Returns / Set the scene product's color and inheritance.
                | 
                |     Parameters:
                | 
                |         iRed
                |             A value between 0 and 255 
                |         iGreen
                |             A value between 0 and 255 
                |         iBlue
                |             A value between 0 and 255 
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |              This example retrieves the activation state of the scenePrd
                |              SceneProductData.
                |
                |             scenePrd.SetRealColor 255,0,0,1

        :param int i_red:
        :param int i_green:
        :param int i_blue:
        :param int i_inheritance:
        :rtype: None
        """
        return self.scene_product_data.SetRealColor(i_red, i_green, i_blue, i_inheritance)

    def set_real_transparency(self, i_transparency: int, i_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRealTransparency(long iTransparency,
                | long iInheritance)
                | 
                |     Set the scene product's Transparency and inheritance.
                | 
                |     Parameters:
                | 
                |         iTransparency
                |             A value between 0 and 255 
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |              This example applies the transparency of the scenePrd
                |              SceneProductData.
                |
                |             scenePrd.SetRealTransparency 10, 1

        :param int i_transparency:
        :param int i_inheritance:
        :rtype: None
        """
        return self.scene_product_data.SetRealTransparency(i_transparency, i_inheritance)

    def __repr__(self):
        return f'SceneProductData(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeCircle(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeCircle
                | 
                | Represents the hybrid shape circle object.
                | Role: To access the data of the hybrid shape circle object.
                | 
                | This data includes:
                | 
                |     The circle radius
                |     Two circle center
                |     The circle arc limitation mode
                |     The circle start and end angles
                | 
                | All interfaces for different type of circle derivates
                | HybridShapeCircle.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeCircle
                | objects.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_circle = com_object

    @property
    def axis_computation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AxisComputation() As boolean
                | 
                |     Returns or sets the axis computation mode.
                | 
                |     Example:
                | 
                |           This example retrieves the axis computation mode of
                |          the hybShpCircle
                |          
                | 
                |          Dim axisComp As Boolean
                |          axisComp = hybShpCircle.AxisComputation

        :rtype: bool
        """

        return self.hybrid_shape_circle.AxisComputation

    @axis_computation.setter
    def axis_computation(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_circle.AxisComputation = value

    @property
    def axis_direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AxisDirection() As HybridShapeDirection
                | 
                |     Role: To get_Direction on the object.
                | 
                |     Parameters:
                | 
                |         oDir
                |             return value for CATScript applications, with (IDLRETVAL) function
                |             type 
                | 
                |     See also:
                |         HybridShapeDirection 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_circle.AxisDirection)

    @axis_direction.setter
    def axis_direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_circle.AxisDirection = direction.com_object

    @property
    def end_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndAngle() As Angle (Read Only)
                | 
                |     Returns the circle end angle.
                | 
                |     Example:
                |         This example retrieves in ShpCircleEndAngle the end angle of the
                |         ShpCircle hybrid shape circle.
                | 
                |          Dim ShpCircleEndAngle As Angle
                |          ShpCircleEndAngle = ShpCircle.EndAngle

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_circle.EndAngle)

    @property
    def start_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property StartAngle() As Angle (Read Only)
                | 
                |     Returns the circle start angle.
                | 
                |     Example:
                |         This example retrieves in ShpCircleStartAngle the end angle of the
                |         ShpCircle hybrid shape circle.
                | 
                |          Dim ShpCircleStartAngle As Angle
                |          ShpCircleStartAngle = ShpCircle.StartAngle

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_circle.StartAngle)

    def get_axis(self, i_position: int, o_axis: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetAxis(long iPosition,
                | Reference oAxis)
                | 
                |     Returns the axis of the Circle.
                | 
                |     Parameters:
                | 
                |         iType
                |             Type of axis to be retrived. 3 - CATGSMAxisLineType_NormalToCircle
                |             2 - CATGSMAxisLineType_NormalToDirection 1 -
                |             CATGSMAxisLineType_AlignedWithDirection 
                |         oAxis
                |             Reference to the element.
                | 
                |             Example:
                |                 This example retrieves the axis of the circle. HybShpCircle
                |                 hybrid shape circle.
                | 
                |                  Dim AxisRef As Reference
                |                  HybShpCircle.GetAxis 1, AxisRef

        :param int i_position:
        :param Reference o_axis:
        :rtype: None
        """
        return self.hybrid_shape_circle.GetAxis(i_position, o_axis.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_axis'
        # # vba_code = """
        # # Public Function get_axis(hybrid_shape_circle)
        # #     Dim iPosition (2)
        # #     hybrid_shape_circle.GetAxis iPosition
        # #     get_axis = iPosition
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_center(self, o_center_x: float, o_center_y: float, o_center_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCenter(double oCenterX,
                | double oCenterY,
                | double oCenterZ)
                | 
                |     Gets the mathematical center of the circle. This information is available
                |     once the circle has been computed.
                | 
                |     Parameters:
                | 
                |         oCenterX,
                |             oCenterY, oCenterZ, circle center

        :param float o_center_x:
        :param float o_center_y:
        :param float o_center_z:
        :rtype: None
        """
        return self.hybrid_shape_circle.GetCenter(o_center_x, o_center_y, o_center_z)

    def get_free_center(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFreeCenter(CATSafeArrayVariant ioCenter)
                | 
                |     Returns the circle center.
                | 
                |     Parameters:
                | 
                |         oCenter
                |             The circle center. It is returned as an array of three coordinates
                |             in SafeArrayVariant 
                | 
                |     Example:
                |         This example retrieves in HybShpCircleCenter the center of the
                |         HybShpCircle hybrid shape circle.
                | 
                |          Dim HybShpCircleCenter
                |          ReDim HybShpCircleCenter(2)
                |          ShpCircle.GetFreeRadius(HybShpCircleCenter)
                |          
                | 
                |         You can access each center coordinate as follows:
                | 
                |             x is in HybShpCircleCenter(0)
                |             y is in HybShpCircleCenter(1)
                |             z is in HybShpCircleCenter(2)

        :rtype: tuple
        """
        vba_function_name = 'get_free_center'
        vba_code = """
        Public Function get_free_center(hybrid_shape_circle)
            Dim ioCenter (2)
            hybrid_shape_circle.GetFreeCenter ioCenter
            get_free_center = ioCenter
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_free_radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFreeRadius(double oRadius)
                | 
                |     Returns the circle radius.
                | 
                |     Parameters:
                | 
                |         oRadius
                |             The circle radius 
                | 
                |     Example:
                |         This example retrieves in HybShpCircleRadius the radius of the
                |         HybShpCircle hybrid shape circle.
                | 
                |          double HybShpCircleRadius
                |          ShpCircle.GetFreeRadius(HybShpCircleRadius)

        :rtype: float
        """
        return self.hybrid_shape_circle.GetFreeRadius()

    def get_limitation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLimitation() As long
                | 
                |     Gets the limitation type for the circle.
                | 
                |     Parameters:
                | 
                |         oLimit
                |             (Angles = 0, Whole = 1, Trimmed = 2, Complementary = 3). circle limitation

        :rtype: int
        """
        return self.hybrid_shape_circle.GetLimitation()

    def set_limitation(self, i_limitation: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLimitation(long iLimitation)
                | 
                |     Set the circle limitation type.
                | 
                |     Parameters:
                | 
                |         iLimitation
                |             The circle limitation type
                |             Legal values:
                | 
                |             0
                |                 Angles 
                |             1
                |                 Whole 
                |             2
                |                 Trimmed 
                |             3
                |                 Complementary 
                | 
                |     Example:
                |         This example sets the limitiation type of the ShpCircle hybrid shape
                |         circle to trimmed.
                | 
                |          ShpCircle.SetLimitation 2

        :param int i_limitation:
        :rtype: None
        """
        return self.hybrid_shape_circle.SetLimitation(i_limitation)

    def __repr__(self):
        return f'HybridShapeCircle(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAppScalingRule(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppScalingRule
                | 
                | Provide application rule of how to scale schematic objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_scaling_rule = com_object

    def app_get_scaling_priority(self, o_priority: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetScalingPriority(long oPriority)
                | 
                |     Get a priority number to indicate the adjustment (moving) priority of this
                |     object during scaling.
                | 
                |     Parameters:
                | 
                |         oPriority
                |             1 to 99. The lower the number, the higher the processing priority.
                |             For example, an object with priority 1 is processed first and will not move
                |             while connected objects adjust. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppScalingRule
                |          Dim intVar1 As Integer
                |           ...
                |          objThisIntf.AppGetScalingPriorityintVar1

        :param int o_priority:
        :rtype: None
        """
        return self.sch_app_scaling_rule.AppGetScalingPriority(o_priority)

    def __repr__(self):
        return f'SchAppScalingRule(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class E5Property(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     E5Property
                | 
                | Interface to access object properties.
                | Role: This interface allow user to access and edit properties for those V5
                | objects who were loaded from E5. Note
                | 
                | While getting or setting the value for any attribute the implementation
                | attempts to access attribute value from V5 object first & then from
                | Manufacturing Hub. If attribute happens to be one of the mapped attribute or if
                | attribute with same name (user attribute, CATIA attribute ...) exists on V5
                | object, then value will be returned from V5 object. If V5 object doesn't have
                | that attribute, then value will be directly returned from Manufacturing Hub
                | database. When we try to get attribute from V5 object, if required object will
                | be loaded in memory and this may result in populating of cache (CGR, Selective
                | loading...)
                | 
                | This interface expect caller to use attribute name define in PPPR server for
                | example caller should use "note" to access Description .
                | 
                | Set calls will succeed only if user has editing privileges for that
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.e5_property = com_object

    def get_boolean_attribute(self, i_attr_name: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBooleanAttribute(CATBSTR iAttrName) As boolean
                | 
                |     This gets an CATBoolean Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             CATBoolean value of the Attribute

        :param str i_attr_name:
        :rtype: bool
        """
        return self.e5_property.GetBooleanAttribute(i_attr_name)

    def get_double_attribute(self, i_attr_name: str) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDoubleAttribute(CATBSTR iAttrName) As double
                | 
                |     This gets a Double Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             Double value of the Attribute

        :param str i_attr_name:
        :rtype: float
        """
        return self.e5_property.GetDoubleAttribute(i_attr_name)

    def get_long_attribute(self, i_attr_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLongAttribute(CATBSTR iAttrName) As long
                | 
                |     This gets a Long Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             Long value of the Attribute

        :param str i_attr_name:
        :rtype: int
        """
        return self.e5_property.GetLongAttribute(i_attr_name)

    def get_string_attribute(self, i_attr_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStringAttribute(CATBSTR iAttrName) As CATBSTR
                | 
                |     This gets a String Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                | 
                |     Returns:
                |         CATUnicodeString value of the Attribute

        :param str i_attr_name:
        :rtype: str
        """
        return self.e5_property.GetStringAttribute(i_attr_name)

    def set_boolean_attribute(self, i_attr_name: str, i_attr_value: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBooleanAttribute(CATBSTR iAttrName,
                | boolean iAttrValue)
                | 
                |     This sets an CATBoolean Attribute value to an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The Attribute Name whose value we need to set 
                |         iAttrValue
                |             CATBoolean value of the Attribute 
                | 
                |     Returns:
                |         Value of iAttrName

        :param str i_attr_name:
        :param bool i_attr_value:
        :rtype: None
        """
        return self.e5_property.SetBooleanAttribute(i_attr_name, i_attr_value)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_boolean_attribute'
        # # vba_code = """
        # # Public Function set_boolean_attribute(e5_property)
        # #     Dim iAttrName (2)
        # #     e5_property.SetBooleanAttribute iAttrName
        # #     set_boolean_attribute = iAttrName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_double_attribute(self, i_attr_name: str, i_attr_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDoubleAttribute(CATBSTR iAttrName,
                | double iAttrValue)
                | 
                |     This sets a Double Attribute value to an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The Attribute Name whose value we need to set 
                |         iAttrValue
                |             Double value of the Attribute 
                | 
                |     Returns:
                |         Value of iAttrName

        :param str i_attr_name:
        :param float i_attr_value:
        :rtype: None
        """
        return self.e5_property.SetDoubleAttribute(i_attr_name, i_attr_value)

    def set_long_attribute(self, i_attr_name: str, i_attr_value: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLongAttribute(CATBSTR iAttrName,
                | long iAttrValue)
                | 
                |     This sets a Long Attribute value to an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The Attribute Name whose value we need to set 
                | 
                |     Returns:
                |         Value of iAttrName

        :param str i_attr_name:
        :param int i_attr_value:
        :rtype: None
        """
        return self.e5_property.SetLongAttribute(i_attr_name, i_attr_value)

    def set_string_attribute(self, i_attr_name: str, i_attr_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStringAttribute(CATBSTR iAttrName,
                | CATBSTR iAttrValue)
                | 
                |     This sets a String Attribute value to an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The Attribute Name whose value we need to set 
                |         iAttrValue
                |             CATUnicodeString value of the Attribute

        :param str i_attr_name:
        :param str i_attr_value:
        :rtype: None
        """
        return self.e5_property.SetStringAttribute(i_attr_name, i_attr_value)

    def __repr__(self):
        return f'E5Property(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_circle import HybridShapeCircle
from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapeCircleCtrRad(HybridShapeCircle):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.HybridShapeCircle
                |                             HybridShapeCircleCtrRad
                | 
                | Represents the hybrid shape circle object defined using a center and a
                | radius.
                | Role: To access the data of the hybrid shape circle object.
                | 
                | This data includes:
                | 
                |     The circle center
                |     The circle radius
                |     The surface that supports the circle
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeCircleCtrRad
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_circle_ctr_rad = com_object

    @property
    def center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Center() As Reference
                | 
                |     Returns or sets the circle center.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in HybShpCircleCenter the center of the
                |         HybShpCircle hybrid shape circle.
                | 
                |          Dim HybShpCircleCenter As Reference
                |          HybShpCircleCenter = HybShpCircle.Center

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_ctr_rad.Center)

    @center.setter
    def center(self, reference_center: Reference):
        """
        :param Reference reference_center:
        """

        self.hybrid_shape_circle_ctr_rad.Center = reference_center.com_object

    @property
    def diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Diameter() As Length (Read Only)
                | 
                |     Returns the circle diameter.
                |     It is expressed as a Length literal. Succeeds only if DiameterMode is set
                |     to True. 
                | 
                | Example:
                |     This example retrieves in HybShpCircleDiameter the diameter of the
                |     HybShpCircle hybrid shape circle feature
                | 
                |      Dim HybShpCircleDiameter As Length
                |      HybShpCircleDiameter = HybShpCircle.Diameter

        :rtype: Length
        """

        return Length(self.hybrid_shape_circle_ctr_rad.Diameter)

    @property
    def diameter_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DiameterMode() As boolean
                | 
                |     Returns or sets the DiameterMode.
                |     Legal values: True implies diameter False implies radius (default). When
                |     DiameterMode is changed, Radius/Diameter value, which is stored will not be
                |     modified.
                | 
                |     Example:
                | 
                |            This example sets that the DiameterMode of
                |           the HybShpCircle hybrid shape circle feature
                |           
                | 
                |           HybShpCircle.DiameterMode = True

        :rtype: bool
        """

        return self.hybrid_shape_circle_ctr_rad.DiameterMode

    @diameter_mode.setter
    def diameter_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_circle_ctr_rad.DiameterMode = value

    @property
    def first_direction(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstDirection() As HybridShapeDirection
                | 
                |     Returns or sets the first direction used to set the angles reference.
                |     
                | 
                | Example:
                |     This example retrieves in myHybridShapeDirection the first direction of the
                |     HybShpCircle hybrid shape circle feature
                | 
                |      Dim myHybridShapeDirection As CATIAHybridShapeDirection 
                |      myHybridShapeDirection = HybShpCircle.FirstDirection
                |      
                | 
                |     See also:
                |         HybridShapeDirection

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_circle_ctr_rad.FirstDirection)

    @first_direction.setter
    def first_direction(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_circle_ctr_rad.FirstDirection = direction.com_object

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Returns the circle radius. It is expressed as a Length literal. Succeeds
                |     only if DiameterMode is set to False. 
                | 
                | Example:
                |     This example retrieves in HybShpCircleRadius the radius of the HybShpCircle
                |     hybrid shape circle.
                | 
                |      Dim HybShpCircleRadius As Length
                |      HybShpCircleRadius = HybShpCircle.Radius

        :rtype: Length
        """

        return Length(self.hybrid_shape_circle_ctr_rad.Radius)

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the circle support surface.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                |         This example retrieves in HybShpCircleSupportSurf the support surface
                |         of the HybShpCircle hybrid shape circle.
                | 
                |          Dim HybShpCircleSupportSurf As Reference 
                |          HybShpCircleSupportSurf = HybShpCircle.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_ctr_rad.Support)

    @support.setter
    def support(self, support_reference: Reference):
        """
        :param Reference support_reference:
        """

        self.hybrid_shape_circle_ctr_rad.Support = support_reference.com_object

    def get_second_direction(self, o_dir_x: float, o_dir_y: float, o_dir_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondDirection(double oDirX,
                | double oDirY,
                | double oDirZ)
                | 
                |     Gets the second direction on the plane to compute the point (for
                |     stability).
                |     This direction has to be kept perpendicular to the first
                |     direction
                | 
                |     Parameters:
                | 
                |         oDirX,
                |             oDirY, oDirZ. second direction 
                | 
                |     See also:
                |         HybridShapeDirection

        :param float o_dir_x:
        :param float o_dir_y:
        :param float o_dir_z:
        :rtype: None
        """
        return self.hybrid_shape_circle_ctr_rad.GetSecondDirection(o_dir_x, o_dir_y, o_dir_z)

    def is_geodesic(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsGeodesic() As boolean
                | 
                |     Queries whether the circle is geodesic or not.
                | 
                |     Parameters:
                | 
                |         oGeod
                |             geodesic type : when TRUE, the circle is geodesic.

        :rtype: bool
        """
        return self.hybrid_shape_circle_ctr_rad.IsGeodesic()

    def set_geometry_on_support(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGeometryOnSupport()
                | 
                |     Sets GeometryOnSupport of circle.
                |     It puts the circle on the surface.

        :rtype: None
        """
        return self.hybrid_shape_circle_ctr_rad.SetGeometryOnSupport()

    def set_second_direction(self, i_dir_x: float, i_dir_y: float, i_dir_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSecondDirection(double iDirX,
                | double iDirY,
                | double iDirZ)
                | 
                |     Sets the second direction on the plane to compute the point (for
                |     stability).
                |     This direction has to be kept perpendicular to the first
                |     direction
                | 
                |     Parameters:
                | 
                |         iDirX,
                |             iDirY, iDirZ. second direction 
                | 
                |     See also:
                |         HybridShapeDirection

        :param float i_dir_x:
        :param float i_dir_y:
        :param float i_dir_z:
        :rtype: None
        """
        return self.hybrid_shape_circle_ctr_rad.SetSecondDirection(i_dir_x, i_dir_y, i_dir_z)

    def unset_geometry_on_support(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub UnsetGeometryOnSupport()
                | 
                |     Inactivates GeometryOnSupport of circle.
                |     Note: The circle becomes euclidean.

        :rtype: None
        """
        return self.hybrid_shape_circle_ctr_rad.UnsetGeometryOnSupport()

    def __repr__(self):
        return f'HybridShapeCircleCtrRad(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_2dL_interfaces.layout_2d_root import Layout2DRoot
from pycatia.system_interfaces.any_object import AnyObject


class Layout2DFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Layout2DFactory

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.layout_2d_factory = com_object

    def create_2d_layout(self, i_standard_name: str) -> Layout2DRoot:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Create2DLayout(CATBSTR iStandardName) As Layout2DRoot
                | 
                |     Create the 2DLayout associated to the 3D mechanical feature tha implement
                |     this interface. E.g. a Mechanical Part.
                | 
                |     Parameters:
                | 
                |         CATBSTR
                |             iStandardName The standard name to apply to the new layout.
                |             
                |         oLayout
                |             The created 2DLayout. This feature is unique for a given 3D context
                |             feature. Consequently requesting this interface on a 3D feature that is already
                |             associated to a 2DLayout feature will fail. You must first request for any
                |             existing 2DLayout via 
                | 
                |         AnyObject.GetItem method using CATLayoutRoot key parameter to check for
                |         2DLayout pre-existing feature as follow :
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot")
                |          if MyRoot Is Nothing then
                |            Dim MyRootFact As Layout2DFactory
                |            Set MyRootFact = CATIA.ActiveDocument.Part.GetItem("CATLayoutRootFactory")
                |            Set MyRoot = MyRootFact.Create2DLayout("ISO_3D")
                |          end if

        :param str i_standard_name:
        :rtype: Layout2DRoot
        """
        return Layout2DRoot(self.layout_2d_factory.Create2DLayout(i_standard_name))

    def __repr__(self):
        return f'Layout2DFactory(name="{self.name}")'
